@@ -5,7 +5,7 @@
 ;; Author: Protesilaos Stavrou <info@protesilaos.com>
 ;; Maintainer: Protesilaos Stavrou <info@protesilaos.com>
 ;; URL: https://github.com/protesilaos/beframe
-;; Version: 1.1.0
+;; Version: 1.1.1
 ;; Package-Requires: ((emacs "28.1"))
 
 ;; This file is NOT part of GNU Emacs.
@@ -552,6 +552,7 @@ Meant to be assigned to a prefix key, like this:
 
     (define-key global-map (kbd \"C-c b\") \=#'beframe-prefix-map)")
 
+;;;###autoload (autoload 'beframe-prefix-map "beframe")
 (define-prefix-command 'beframe-prefix-map)
 
 (define-key beframe-prefix-map (kbd "b") #'beframe-switch-buffer)
@@ -618,13 +619,14 @@ Also see the variable `beframe-prefix-map'."
 (defun beframe-infer-frame-name (frame name)
   "Infer a suitable name for FRAME with given NAME.
 See `beframe-rename-frame'."
-  (let* ((buffer (car (frame-parameter frame 'buffer-list)))
-         (file-name (when (bufferp buffer) (buffer-file-name buffer)))
-         (buf-name (buffer-name buffer))
-         (dir (with-current-buffer buffer (or (vc-root-dir) default-directory)))
-         (projectp (and (bound-and-true-p project--list)
-                        (listp project--list)
-                        (member (list dir) project--list))))
+  (when-let (((frame-list))
+             (buffer (car (frame-parameter frame 'buffer-list)))
+             (file-name (when (bufferp buffer) (buffer-file-name buffer)))
+             (buf-name (buffer-name buffer))
+             (dir (with-current-buffer buffer (or (vc-root-dir) default-directory)))
+             (projectp (and (bound-and-true-p project--list)
+                            (listp project--list)
+                            (member (list dir) project--list))))
     (cond
      ((and name (stringp name))
       name)
